" Maintainer: Benjamin Linskey <vim@benlinskey.com>
" Last Changed: 2016 December 5
" URL: https://github.com/blinskey/vim-armenian-keymaps

let b:keymap_name = "hy"

loadkeymap

" Capital letters
A   Ա
P   Բ
C   Գ
T   Դ
Y   Ե
Z   Զ
E   Է
U   Ը
:   Թ
+   Ժ
I   Ի
L   Լ
Q   Խ
?   Ծ
G   Կ
H   Հ
@   Ձ
>   Ղ
J   Ճ
M   Մ
#   Յ
N   Ն
<   Շ
O   Ո
{   Չ
B   Պ
}   Ջ
_   Ռ
S   Ս
W   Վ
D   Տ
R   Ր
X   Ց
V   Ւ
\"  Փ
K   Ք
)   Օ
F   Ֆ

" Lowercase letters
a   ա
p   բ
c   գ
t   դ
y   ե
z   զ
e   է
u   ը
;   թ
=   ժ
i   ի
l   լ
q   խ
/   ծ
g   կ
h   հ
2   ձ
.   ղ
j   ճ
m   մ
3   յ
n   ն
,   շ
o   ո
[   չ
b   պ
]   ջ
-   ռ
s   ս
w   վ
d   տ
r   ր
x   ց
v   ւ
'   փ
k   ք
0   օ
f   ֆ

&   և

" Punctuation
`   ՝
~   ՜
1   ։
4   ՛
5   ,
6   -
7   .
8   «
9   »
*   (
(   )
\\  '
|   ՞

" Numbers
!   1
$   3
%   4
^   9
