" Vim syntax file
" Language:	apkbuild
" Maintainer:	Vim Classic <https://vim-classic.org>
" Last Change:	2026-04-02

" quit when a syntax file was already loaded
if exists("b:current_syntax")
  finish
endif

" The actual syntax is in sh.vim and controlled by buffer-local variables.
unlet! b:is_sh
unlet! b:is_kornshell
let b:is_bash = 1

runtime! syntax/sh.vim

let b:current_syntax = 'apkbuild'
