" Script to fill the window with emoji characters, one per line.
" Source this script: :source %

if &modified
  new
else
  enew
endif

func DoIt()
  let lnum = 1
  for c in range(0x100, 0x1ffff)
    let cs = nr2char(c)
    if charclass(cs) == 3
      call setline(lnum, '|' .. cs .. '| ' .. strwidth(cs))
      let lnum += 1
    endif
  endfor
endfunc

call DoIt()
set nomodified
